@@ -44,6 +44,10 @@ The following object methods are supported:
  deleteOnTermination -- Whether this EBS will be deleted when the
                 instance terminates. Note that this will return
                 perl 0/1 values rather than the strings "false"/"true"
+ volumeType  -- The volume type, one of "standard" or "iol"
+ iops        -- The number of I/O operations per second that the volume
+                supports, an integer between 1 and 1000. Only valid for
+                volumes of type "iol".
 
 =head1 STRING OVERLOADING
 
@@ -75,7 +79,7 @@ use base 'VM::EC2::Generic';
 
 sub valid_fields {
     my $self = shift;
-    return qw(snapshotId volumeSize deleteOnTermination);
+    return qw(snapshotId volumeSize deleteOnTermination volumeType iops);
 }
 
 sub deleteOnTermination {
